Functions
- canonicalize_
ipnet - Canonicalize an IP network by ensuring it uses the network address
- hash_
u64 - Hash a value to u64 using the default hasher
- host_
size_ key - Host size key function for sorting - equivalent to Python’s host_size_key Returns (priority, string_repr) where priority is:
- ipnet_
to_ bits - Convert an IP network to a vector of bits for radix tree traversal
- normalize_
dns - Normalize a DNS hostname to canonical form (IDNA + lowercase)